%define         major                    39

%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -s -d

Summary:        A highly configurable open-source workload manager
Name:           slurm
Version:        23.02.3
Release:        %mkrel 1
License:        GPLv2+
Group:          System/Cluster

Url:            https://www.schedmd.com/index.php

Source0:        https://download.schedmd.com/slurm/%{name}-%{version}.tar.bz2
Source1:        slurm.conf
Source2:        slurmd.service
Source3:        slurmctld.service
Source4:        slurmdbd.service
Source5:        slurm-tmpfiles.conf
Source6:        slurmdbd.conf
Source7:        cgroup.conf

BuildRequires:  pkg-config
BuildRequires:  autoconf
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  man2html
BuildRequires:  hwloc
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  pkgconfig(lua)
%ifnarch %arm
BuildRequires:  pkgconfig(numa)
%endif
BuildRequires:  pkgconfig(mariadb)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libfreeipmi)
BuildRequires:  pkgconfig(librrd)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(libcgroup)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  readline-devel
BuildRequires:  hdf5
BuildRequires:  hdf5-devel
BuildRequires:  yaml-devel
BuildRequires:  pam-devel
BuildRequires:  http-parser-devel
BuildRequires:  openpmix-devel


Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}




%description
Slurm is a highly configurable open-source workload manager designed
specifically to satisfy the demanding needs of high performance
computing. Slurm is in widespread use at government laboratories,
universities and companies world wide and performs workload management
for over half of the top 10 systems in the TOP500. Use of optional
plugins provides the functionality needed to satisfy the needs of
demanding high performance computing centers. More complex
configurations rely upon a database for archiving accounting records,
managing resource limits by user or bank account, and supporting
sophisticated scheduling algorithms.



%package -n %{libname}
Summary:        Shared libraries for Slurm
Group:          Development/Other
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
%{summary}.



%package -n %{develname}
Summary:        Development files for Slurm
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel  = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
%{summary}.



%package -n %{staticdevelname}
Summary:        Static Development files for Slurm
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-static-devel  = %{version}-%{release}
Provides:       %{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
%{summary}.




%prep

%setup -q


%build
%define _legacy_common_support 1

%configure      \
%ifarch %ix86 %arm
               --enable-deprecated \
%endif
                --with-pmix=%{_prefix} \
                --without-rpath \
                --without-nvml  \
                --without-rsmi
%make_build


%install
%make_install

%{__install} -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/slurmd.service
%{__install} -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/slurmctld.service
%{__install} -D -p -m 0600 %{SOURCE4} %{buildroot}%{_unitdir}/slurmdbd.service
%{__install} -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/slurmdbd.conf
%{__install} -D -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/cgroup.conf

%{__install} -d -m 755 %{buildroot}/%{_localstatedir}/spool/slurmctld
%{__install} -d -m 755 %{buildroot}/%{_logdir}/slurm

find %{buildroot}%{_libdir} -name *.la -delete



%pre
%_pre_useradd %{name} /dev/null /bin/false
%_pre_groupadd %{name}

%post
%_tmpfilescreate %{name}
%_post_service slurmd
%_post_service slurmctld
%_post_service slurmdbd

%preun
%_preun_service slurmd
%_preun_service slurmctld
%_preun_service slurmdbd

%postun
%_postun_userdel %{name}



%files
%doc README.rst AUTHORS CONTRIBUTING.md COPYING DISCLAIMER NEWS RELEASE_NOTES
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %attr(0600,%{name},%name) %{_sysconfdir}/slurmdbd.conf
%config(noreplace) %{_sysconfdir}/cgroup.conf
%{_unitdir}/slurmd.service
%{_unitdir}/slurmctld.service
%{_unitdir}/slurmdbd.service
%{_tmpfilesdir}/%{name}.conf
%attr(-, slurm, slurm) %dir %{_localstatedir}/spool/slurmctld
%attr(-, slurm, slurm) %dir %{_logdir}/slurm

%{_sbindir}/*
%{_bindir}/*
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*
%{_docdir}/%{name}-%{version}

%files -n %{libname} 
%{_libdir}/libslurm.so.%{major}{,.*}
#looks like these guys are modules, not devel files
%{_libdir}/slurm/*.so

%files -n %{develname}
%{_includedir}/slurm
%{_libdir}/*.so
%{_libdir}/%{name}/src

%files -n %{staticdevelname}
%{_libdir}/*.a
%{_libdir}/%{name}/*.a


%changelog
* Wed Jun 28 2023 eatdirt <eatdirt> 23.02.3-1.mga9
+ Revision: 1963263
- Update to version 23.02.3

* Wed Jun 07 2023 eatdirt <eatdirt> 23.02.2-1.mga9
+ Revision: 1961182
- Update to bug fix release 23.02.2

* Wed Apr 05 2023 eatdirt <eatdirt> 23.02.1-2.mga9
+ Revision: 1951504
- Fix installation of config files

* Wed Apr 05 2023 eatdirt <eatdirt> 23.02.1-1.mga9
+ Revision: 1951480
- Update to version 23.02.1

* Fri Mar 17 2023 eatdirt <eatdirt> 23.02.0-1.mga9
+ Revision: 1949616
- Upgrade to version 23.02.0

* Fri Jan 20 2023 eatdirt <eatdirt> 22.05.7-1.mga9
+ Revision: 1934496
- Update to version 22.05.7

* Mon Dec 05 2022 papoteur <papoteur> 22.05.6-2.mga9
+ Revision: 1918284
- rebuild for hdf5 1.12.2

* Sat Dec 03 2022 eatdirt <eatdirt> 22.05.6-1.mga9
+ Revision: 1916130
- Update to version 22.05.6

* Fri Aug 26 2022 eatdirt <eatdirt> 22.05.3-1.mga9
+ Revision: 1880468
- Upgrade to version 22.05.3

* Thu May 05 2022 eatdirt <eatdirt> 21.08.8-1.mga9
+ Revision: 1856351
- Upgrade to version 21.08.8

* Sat Apr 02 2022 umeabot <umeabot> 21.08.4-2.mga9
+ Revision: 1841180
- Mageia 9 Mass Rebuild

* Wed Dec 01 2021 neoclust <neoclust> 21.08.4-1.mga9
+ Revision: 1760218
- New version 21.08.4: Fixes CVE-2021-43337 (mga#29709)

* Fri Oct 01 2021 joequant <joequant> 21.08.1-1.mga9
+ Revision: 1747001
- update to 21.08 / lua 5.4

* Fri Aug 27 2021 eatdirt <eatdirt> 20.11.8-2.mga9
+ Revision: 1742889
- Rebuild for new pmix

* Fri Aug 27 2021 eatdirt <eatdirt> 20.11.8-1.mga9
+ Revision: 1742716
- Upgrade to version 20.11.8

* Mon May 31 2021 eatdirt <eatdirt> 20.11.7-1.mga9
+ Revision: 1728952
- Upgrade to version 20.11.7

* Fri Apr 02 2021 wally <wally> 20.11.2-2.mga9
+ Revision: 1712819
- rebuild for lua 5.4

* Thu Dec 24 2020 eatdirt <eatdirt> 20.11.2-1.mga8
+ Revision: 1663448
- Upgrade to version 20.11.2

* Sat Dec 12 2020 eatdirt <eatdirt> 20.11.1-1.mga8
+ Revision: 1656040
- Upgrade to version 20.11.1

* Sun Dec 06 2020 eatdirt <eatdirt> 20.11.0-1.mga8
+ Revision: 1653798
- Upgrade to version 20.11.0 (api change but leaf package)

* Mon Nov 30 2020 luigiwalser <luigiwalser> 20.02.6-1.mga8
+ Revision: 1650737
- 20.02.6
- rebuild for json-c

* Tue Oct 13 2020 eatdirt <eatdirt> 20.02.5-1.mga8
+ Revision: 1635395
- Upgrade to version 20.02.5

* Thu Sep 03 2020 eatdirt <eatdirt> 20.02.4-1.mga8
+ Revision: 1621339
- Upgrade to version 20.02.4

* Sat Jul 11 2020 eatdirt <eatdirt> 20.02.3-1.mga8
+ Revision: 1605155
- Upgrade to version 20.02.3

* Fri Jul 03 2020 joequant <joequant> 20.02.0-7.mga8
+ Revision: 1601612
- fix gcc10 patch

* Fri Mar 20 2020 eatdirt <eatdirt> 20.02.0-6.mga8
+ Revision: 1558107
- Create a simple working configuration with associated systemd services

* Thu Mar 19 2020 eatdirt <eatdirt> 20.02.0-5.mga8
+ Revision: 1558087
- Rebuild with libpmix

* Thu Mar 19 2020 eatdirt <eatdirt> 20.02.0-4.mga8
+ Revision: 1558069
- Tentative build for arm

* Thu Mar 19 2020 eatdirt <eatdirt> 20.02.0-3.mga8
+ Revision: 1558049
- Remove BR to numa on arm

* Thu Mar 19 2020 eatdirt <eatdirt> 20.02.0-2.mga8
+ Revision: 1558029
- Use new configure macro
- imported package slurm

